package main

import (
	"fmt"
	"os"

	"github.com/spf13/cobra"

	"go.salty.im/saltyim/internal/app"
)

var chatCmd = &cobra.Command{
	Use:     "chat [user]",
	Aliases: []string{"talk"},
	Short:   "Creates a chat with a specific user",
	Long: `This command creates a chat with the specified user by discovering
and subscribing to your endpoint and prompts for input and sends encrypted
messages to the user via their discovered endpoint.`,
	Args:     cobra.MaximumNArgs(1),
	PreRunE:  initializeClient,
	PostRunE: shutdownClient,
	Run: func(cmd *cobra.Command, args []string) {
		if len(args) == 1 {
			chat(args[0])
		} else {
			chat("")
		}
	},
}
var defaultCmd = chatCmd

func init() {
	rootCmd.AddCommand(chatCmd)
}

func chat(user string) {
	// Set terminal title
	if user != "" {
		app.SetTerminalTitle("Salty IM with %s", user)
	} else {
		app.SetTerminalTitle("Salty IM")
	}

	// Initialize the app
	app, err := app.NewApp(cli)
	if err != nil {
		fmt.Fprintf(os.Stderr, "error creating chat: %s\n", err)
		os.Exit(2)
	}

	if user != "" {
		if err := app.ChatWith(user); err != nil {
			fmt.Fprintf(os.Stderr, "error creating chat with %q: %s\n", user, err)
			os.Exit(2)
		}
	}

	// Run the ui loop
	if err := app.Run(); err != nil {
		fmt.Fprintf(os.Stderr, "error running chat with: %s\n", err)
		os.Exit(2)
	}
}
