package main

import (
	"bytes"
	"fmt"
	"strings"
	"text/template"

	log "github.com/sirupsen/logrus"
	"github.com/spf13/cobra"
	"github.com/spf13/viper"
	"go.salty.im/saltyim"
)

var cli *saltyim.Client

func initializeClient(cmd *cobra.Command, args []string) error {
	identity := viper.GetString("identity")
	log.Debugf("identity: %s", identity)

	user := viper.GetString("user")
	log.Debugf("user: %s", user)

	var profiles []profile
	viper.UnmarshalKey("profiles", &profiles)
	log.Debugf("profiles: %#v", profiles)
	for _, p := range profiles {
		if user == p.User {
			identity = p.Identity
		}
	}
	log.Debugf("identity: %s", identity)

	me, err := saltyim.ParseAddr(user)
	if err != nil {
		log.Debugf("error parsing addr: %s\n", err)
	}
	log.Debugf("me: %s", me)

	id, err := saltyim.GetIdentity(saltyim.WithIdentityPath(identity))
	if err != nil {
		return fmt.Errorf("error loading identity %s: %w", identity, err)
	}

	state := viper.GetString("state")

	opts := []saltyim.ClientOption{
		saltyim.WithIdentity(id),
		saltyim.WithStateFromFile(state),
	}
	userFlag, _ := cmd.Flags().GetString("user")
	log.Debugf(`id.Addr(): %s`, id.Addr())
	log.Debugf(`viper.GetString("user"): %s`, viper.GetString("user"))
	log.Debugf(`cmd.Flags().GetString("user"): %s`, userFlag)
	if id.Addr().IsZero() || (strings.EqualFold(userFlag, viper.GetString("user"))) {
		opts = append(opts, saltyim.WithUser(viper.GetString("user")))
	}

	cli, err = saltyim.NewClient(opts...)
	if err != nil {
		return fmt.Errorf("error initializing client: %w", err)
	}

	return nil
}

func shutdownClient(cmd *cobra.Command, args []string) error {
	state := viper.GetString("state")
	if state == "" {
		return nil
	}

	if err := cli.State().Save(state); err != nil {
		return fmt.Errorf("error saving state to %s: %w", state, err)
	}

	return nil
}

func renderString(s string, ctx interface{}) (string, error) {
	t := template.Must(template.New("s").Parse(s))
	buf := bytes.NewBuffer([]byte{})
	err := t.Execute(buf, ctx)
	if err != nil {
		return "", err
	}

	return buf.String(), nil
}

func mustRenderString(s string, ctx interface{}) string {
	out, err := renderString(s, ctx)
	if err != nil {
		log.WithError(err).Fatal("error rendering string template")
	}
	return out
}
