package saltyim_test

import (
	"os"
	"path/filepath"
	"testing"

	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
	"go.salty.im/saltyim"
)

const (
	testAddr         = "alice@example.com"
	testIdentityPath = "alice.key"
)

func TestIdentity(t *testing.T) {
	assert := assert.New(t)
	require := require.New(t)

	dir, err := os.MkdirTemp("", "salty")
	require.NoError(err)
	defer os.RemoveAll(dir)

	addr, err := saltyim.ParseAddr(testAddr)
	require.NoError(err)

	fn := filepath.Join(dir, testIdentityPath)
	ident1, err := saltyim.CreateIdentity(saltyim.WithIdentityAddr(addr), saltyim.WithIdentityPath(fn))
	require.NoError(err)
	assert.NotNil(ident1.Key())
	assert.Equal(addr.String(), ident1.Addr().String())

	ident2, err := saltyim.GetIdentity(saltyim.WithIdentityAddr(addr), saltyim.WithIdentityPath(fn))
	require.NoError(err)
	assert.NotNil(ident2.Key())
	assert.Equal(addr.String(), ident2.Addr().String())
}
