package app

import (
	"fmt"
	"strings"

	"github.com/gdamore/tcell/v2"
	"github.com/rivo/tview"
	colorhash "github.com/taigrr/go-colorhash"
)

func getUserColor(s string) tcell.Color {
	c := colorhash.HashString(s)
	return tcell.NewHexColor(int32(c))
}

func floatingModal(p tview.Primitive, width, height int) tview.Primitive {
	return tview.NewFlex().
		AddItem(nil, 0, 1, false).
		AddItem(tview.NewFlex().SetDirection(tview.FlexRow).
			AddItem(nil, 0, 1, false).
			AddItem(p, height, 1, true).
			AddItem(nil, 0, 1, false), width, 1, true).
		AddItem(nil, 0, 1, false)
}

// getMessageWidth returns width size for dialogs based on messages.
func getMessageWidth(message string) int {
	var messageWidth int
	for _, msg := range strings.Split(message, "\n") {
		if len(msg) > messageWidth {
			messageWidth = len(msg)
		}
	}

	return messageWidth
}

// SetTerminalTitle sets the Terminal/Console's title
func SetTerminalTitle(format string, args ...interface{}) {
	fmt.Printf("\033]0;%s\007", fmt.Sprintf(format, args...))
}
